@@ -32,7 +32,7 @@ window.cockpit_po = {
  ],
  "$0 is not available from any repository.": [
   null,
-  "$0 n’est disponible dans aucun référentiel."
+  "$0 n’est disponible dans aucun dépôt."
  ],
  "$0 key changed": [
   null,
@@ -132,7 +132,7 @@ window.cockpit_po = {
  ],
  "Additional packages:": [
   null,
-  "Paquets supplémentaires :"
+  "Paquets supplémentaires :"
  ],
  "Administration with Cockpit Web Console": [
   null,
@@ -404,7 +404,7 @@ window.cockpit_po = {
  ],
  "Hide password": [
   null,
-  "Masquer le mot de passe."
+  "Masquer le mot de passe"
  ],
  "Host is unknown": [
   null,
@@ -986,10 +986,6 @@ window.cockpit_po = {
   null,
   "Tower"
  ],
- "Transient packageless sessions require the same operating system and version, for compatibility reasons: $0.": [
-  null,
-  "Pour des raisons de compatibilité, les systèmes d'exploitation utilisés et leur version doivent correspondre afin de pouvoir utiliser les sessions packageless transitoires : $0."
- ],
  "Trust and add host": [
   null,
   "Faire confiance à l'hôte et l'ajouter"
@@ -1022,6 +1018,10 @@ window.cockpit_po = {
   null,
   "Hôte inconnu : $0"
  ],
+ "Unsupported shell. Check the journal for details.": [
+  null,
+  "Shell non pris en charge. Consultez le journal pour connaître les détails."
+ ],
  "Untrusted host": [
   null,
   "Hôte non sécurisé"
